#!/bin/bash

function prompt {
    echo $1
    read -rsn1 -p "   Press any key to execute...";echo
    eval $1
    read -rsn1 -p "   Press any key to continue...";echo
    clear
}

prompt "openssl list-cipher-algorithms"                                                   ## cipher suites
prompt "openssl s_client -connect www.google.com:443 -showcerts"                          ## HTTPS to Google
prompt "openssl dgst -sha256 hashIn1.txt"                                                 ## sha256 of hashIn1.txt
prompt "openssl dgst -sha256 hashIn2.txt"                                                 ## sha256 of hashIn2.txt
prompt "openssl genpkey -out privkey.pem -algorithm rsa 2048"                             ## generate 2048-bit private key
prompt "openssl rsa -in privkey.pem -outform PEM -pubout -out pubkey.pem"                 ## extract public key
prompt "openssl dgst -sha256 -sign privkey.pem -out sign.sha256 client.c"                 ## sign client.c
prompt "openssl enc -base64 -in sign.sha256 -out sign.sha256.base64"                      ## get base64 encoding of signature
prompt "openssl enc -base64 -d -in sign.sha256.base64 -out sign.sha256"                   ## decode base64 signature
prompt "openssl dgst -sha256 -verify pubkey.pem -signature sign.sha256 client"            ## verify signature
prompt "openssl req -new \              
         -newkey rsa:2048 -nodes -keyout privkeyDC.pem \
         -out myserver.csr \ 
         -subj '/C=US/ST=Illinois/L=Chicago/O=Faulty Consulting/OU=IT/CN=myserver.com'"   ## CRT, no interaction
prompt "openssl req -text -in myserver.csr -noout -verify"                                ## inspect, verify request
prompt "openssl req -x509 -sha256 -nodes -days 365 -newkey rsa:4096 \                    
         -keyout myserver.pem -out myserver.crt"                                          ## self-signed cert
prompt "openssl x509 -in myserver.crt -text -noout"                                       ## readable version of cert
prompt "openssl x509 -noout -modulus -in myserver.crt | openssl sha1"                     ## modulus from the CRT
prompt "openssl rsa -noout -modulus -in myserver.pem | openssl sha1"                      ## modulus from the PEM
